/*
 * Copyright (C) 2025. Nyabsi <nyabsi@sovellus.cc>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cc.sovellus.vrcaa.api.vrchat.http.interfaces

import cc.sovellus.vrcaa.api.vrchat.http.models.User

interface IAuth {

    enum class AuthType {
        AUTH_NONE,
        AUTH_TOTP,
        AUTH_OTP, // <!-- UNSUPPORTED
        AUTH_EMAIL
    }

    data class AuthResult(val success: Boolean, val message: String = "", val authType: AuthType = AuthType.AUTH_NONE)

    suspend fun login(username: String, password: String): AuthResult
    suspend fun verify(type: AuthType, code: String): AuthResult
    suspend fun logout(): Boolean

    suspend fun fetchToken(): String?
    suspend fun fetchCurrentUser(): User?
}